package com.ruoyi.back.mapper;

import com.ruoyi.back.domain.BCustomerQuestionError;

import java.util.List;

/**
 * 题目纠错Mapper接口
 * 
 * @author mingxue
 * @date 2021-11-29
 */
public interface BCustomerQuestionErrorMapper 
{
    /**
     * 查询题目纠错
     * 
     * @param id 题目纠错ID
     * @return 题目纠错
     */
    public BCustomerQuestionError selectBCustomerQuestionErrorById(Long id);

    /**
     * 查询题目纠错列表
     * 
     * @param bCustomerQuestionError 题目纠错
     * @return 题目纠错集合
     */
    public List<BCustomerQuestionError> selectBCustomerQuestionErrorList(BCustomerQuestionError bCustomerQuestionError);

    /**
     * 新增题目纠错
     * 
     * @param bCustomerQuestionError 题目纠错
     * @return 结果
     */
    public int insertBCustomerQuestionError(BCustomerQuestionError bCustomerQuestionError);

    /**
     * 修改题目纠错
     * 
     * @param bCustomerQuestionError 题目纠错
     * @return 结果
     */
    public int updateBCustomerQuestionError(BCustomerQuestionError bCustomerQuestionError);

    /**
     * 删除题目纠错
     * 
     * @param id 题目纠错ID
     * @return 结果
     */
    public int deleteBCustomerQuestionErrorById(Long id);

    /**
     * 批量删除题目纠错
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBCustomerQuestionErrorByIds(Long[] ids);
}
